#!/usr/bin/env python3

import dialog
import fileinput
import os
import sys
import re
import lsb_release

sys.path.append("/linuxcash/cash/tools/tools_avail")
from py_tools.logger import logger

log = logger.Logger()

def create_dialog():
    """
    Создать объект диалога
    """
    d = dialog.Dialog()
    d.add_persistent_args(("--backtitle", "Выбор интерфейса"))
    return d


def createChooseInterfaceDialog(d):
    """
    Создать диалог выбора интерфейса
    """
    isBionic = lsb_release.get_distro_information()['CODENAME'] == 'bionic'
    if isBionic:
        interfaces = [('keyboard', 'Обычный интерфейс', 1),
                      ('touch', 'Сенсорный интерфейс', 0)]
    else:
        interfaces = [('keyboard', 'Обычный интерфейс', 1),
                      ('touch', 'Сенсорный интерфейс', 0),
                      ('touch (legacy)', 'Сенсорный интерфейс (старая версия)', 0)]

    (code, tag) = d.radiolist(
        'Выберите тип интерфейса кассы',
        width=60, height=len(interfaces) + 7,
        choices=interfaces)

    if code == d.OK:
        theme = None
        if not isBionic and tag == 'touch':
            interface = 'theme'
            theme = 'touch'
        elif tag == 'touch (legacy)':
            interface = 'touch'
        else:
            interface = tag
        return True, interface, theme
    else:
        return False, None, None


def writeInterface(interface, theme):
    """
    Записать тип интерфейса в конфигурационный файл
    """
    confFile = '/linuxcash/cash/conf/ncash.ini.d/gui.ini'
    if not os.path.isfile(confFile):
        log.error('Файл %s не существует' % confFile)
        return

    themeWasSet = False
    with fileinput.FileInput(confFile, inplace=True) as file:
        inTheme = False
        inGui = False
        for line in file:
            # Определяем секцию
            if line.startswith('['):
                if re.search('(?i)gui', line):
                    inGui = True
                    inTheme = False
                elif re.search('(?i)theme', line):
                    inGui = False
                    inTheme = True
                else:
                    inTheme = False
                    inGui = False

            # Пишем строку в файл, модифицируем интерфейс и тему
            if inGui and re.search('interface\s*=', line):
                modified_line = line.replace(line, 'interface = ' + interface)
                print(modified_line)
            elif theme and inTheme and re.search('name\s*=', line):
                modified_line = line.replace(line, 'name = ' + theme)
                print(modified_line)
                themeWasSet = True
            else:
                print(line, end='')

    # Если раннее в файле не была указана тема, то дописываем в конец сецкию
    if theme and not themeWasSet:
        with open(confFile, 'a+') as file:
            file.write(f'\n[Theme]\nname = {theme}\n')


def main():
    """
    Главная функция
    """
    log.info("Выбор интерфейса")
    d = create_dialog()
    (res, interface, theme) = createChooseInterfaceDialog(d)
    if not res:
        exit(0)

    writeInterface(interface, theme)
    log.info("Завершение выбора интерфейса")


if __name__ == "__main__":
    os.chdir(os.path.dirname(os.path.abspath(__file__)))
    try:
        main()
    except KeyboardInterrupt:
        log.warn('Неожиданное завершение редактирования выбора интерфейса')
        exit(1)
